==> illumination_0.1.20100120-1.tar.gz: illumination-0.1.20100120/include/Lum/Model/Time.h <==
#ifndef LUM_MODEL_TIME_H
#define LUM_MODEL_TIME_H

/*
  This source is part of the Illumination library
  Copyright (C) 2005  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/Base/DateTime.h>

#include <Lum/Model/Simple.h>

namespace Lum {
  namespace Model {

    class LUMAPI Time : public Simple<Base::Time>
    {
    public:
      Time() : Simple<Base::Time>() {}
      Time(const Base::Time& value) : Simple<Base::Time>(value) {}

      void SetToNow();
      void SetTime(unsigned char hour, unsigned char minute, unsigned char second=0);
      void IncHour();
      void DecHour();
      void IncMinute();
      void DecMinute();
      void IncSecond();
      void DecSecond();
    };

#if defined(LUM_INSTANTIATE_TEMPLATES)
    LUM_EXPTEMPL template class LUMAPI Base::Reference<Time>;
#endif

    typedef Base::Reference<Time> TimeRef;
  }
}

#endif

==> illumination_0.2.20101221-1.tar.gz: illumination-0.2.20101221/include/Lum/Model/Time.h <==
#ifndef LUM_MODEL_TIME_H
#define LUM_MODEL_TIME_H

/*
  This source is part of the Illumination library
  Copyright (C) 2005  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/Base/DateTime.h>

#include <Lum/Model/Simple.h>

namespace Lum {
  namespace Model {

    class LUMAPI Time : public Simple<Base::Time>
    {
    public:
      Time() : Simple<Base::Time>() {}
      Time(const Base::Time& value) : Simple<Base::Time>(value) {}

      bool SetToNow();
      bool SetTime(unsigned char hour, unsigned char minute, unsigned char second=0);
      void IncHour();
      void DecHour();
      void IncMinute();
      void DecMinute();
      void IncSecond();
      void DecSecond();
    };

#if defined(LUM_INSTANTIATE_TEMPLATES)
    LUM_EXPTEMPL template class LUMAPI Base::Reference<Time>;
#endif

    typedef Base::Reference<Time> TimeRef;
  }
}

#endif
